<?php
// Global variables define
define('TROMAS_PARENT_TEMPLATE_DIR_URI', get_template_directory_uri());
define('TROMAS_CHILD_TEMPLATE_DIR_URI', get_stylesheet_directory_uri());
define('TROMAS_CHILD_TEMPLATE_DIR', trailingslashit(get_stylesheet_directory()));

if (!function_exists('wp_body_open')) {

    function wp_body_open() {
        /**
         * Triggered after the opening <body> tag.
         */
        do_action('wp_body_open');
    }

}
add_action('after_setup_theme', 'tromas_setup');

function tromas_setup() {
    load_theme_textdomain('tromas', TROMAS_CHILD_TEMPLATE_DIR . '/languages');

require(TROMAS_CHILD_TEMPLATE_DIR . '/inc/customizer/footer-options.php');
require( TROMAS_CHILD_TEMPLATE_DIR . '/inc/customizer/customizer_theme_style.php');
}

add_action('wp_enqueue_scripts', 'tromas_enqueue_styles');

function tromas_enqueue_styles() {
	if(get_theme_mod('custom_color_enable') == true) {
				tromas_custom_light();
		}
     wp_enqueue_style('tromas-parent-style', TROMAS_PARENT_TEMPLATE_DIR_URI . '/style.css', array( 'bootstrap' ) );
     wp_style_add_data( 'tromas-parent-style', 'rtl', 'replace' );
     wp_enqueue_style('tromas-child-style', TROMAS_CHILD_TEMPLATE_DIR_URI . '/style.css');
     wp_style_add_data( 'tromas-child-style', 'rtl', 'replace' );
     wp_enqueue_style('tromas-default-style', TROMAS_CHILD_TEMPLATE_DIR_URI . '/assets/css/default.css');
     wp_style_add_data( 'tromas-default-style', 'rtl', 'replace' );
     wp_enqueue_script('tromas-mp-masonry-js', TROMAS_CHILD_TEMPLATE_DIR_URI . '/js/masonry/mp.mansory.js', array('jquery'), '', true);
}

if (is_admin()) {
    require get_stylesheet_directory() . '/admin/admin-init.php';
}

function tromas_custom_light(){
	$tromas_link_color = get_theme_mod('link_color');
    list($r, $g, $b) = sscanf($tromas_link_color, "#%02x%02x%02x");
    $r = $r - 50;
    $g = $g - 25;
    $b = $b - 40;

    if ( $tromas_link_color != '#ff0000' ) :
    ?>
<style type="text/css">
	.header-sidebar {
    background: <?php echo esc_attr($tromas_link_color);?> !important;
}
.navbar.navbar7 .site-title-name:hover,.navbar.navbar7  .site-title-name:focus{color: <?php echo esc_attr($tromas_link_color);?> !important;}
.services4 .post {
    background:  <?php echo esc_attr($tromas_link_color);?> !important;
    }
.services4 .entry-header .entry-title a:hover{
    color:#061018!important;
    }
#testimonial-carousel2 .testmonial-block:before {
    border-top: 25px solid <?php echo esc_attr($tromas_link_color);?> !important;
}
#testimonial-carousel2 .testmonial-block {
    border-left: 4px solid <?php echo esc_attr($tromas_link_color);?> !important;
}
.navbar.navbar7 .nav .dropdown-menu {
    border-bottom: 3px solid <?php echo esc_attr($tromas_link_color);?> !important;
}
.navbar.navbar7 .nav .dropdown-menu.search-panel {
    border-bottom: unset !important;
}
.services5 .post .post-thumbnail:after {
    background-color: <?php echo esc_attr($tromas_link_color);?> !important;
}
.services5 .post:hover {
    border-bottom: 5px solid <?php echo esc_attr($tromas_link_color);?> !important;
}
.services5 .post .post-thumbnail {
    border: 10px solid <?php echo esc_attr($tromas_link_color);?> !important;
}
.post-content .entry-header .entry-title a:hover,
.post-content .entry-header .entry-title a:focus {
	color: <?php echo esc_attr($tromas_link_color);?> !important;
}

.post .entry-meta .tag-links a:focus{
    color: <?php echo esc_attr($tromas_link_color);?> !important;
    outline: thin dotted;
    background-color: #fff !important;
}
body .widget .tag-cloud-link:hover, body .widget .tag-cloud-link:focus, body .site-footer .widget .tag-cloud-link:hover, body .site-footer .widget .tag-cloud-link:focus {
    background-color: <?php echo esc_attr($tromas_link_color);?> ;
    border: 1px solid <?php echo esc_attr($tromas_link_color);?> ;
}
body .site-footer .widget .tag-cloud-link:hover { color: #ffffff !important; }

</style>
<?php endif; }

//Set for old user before 1.3.8
if (!get_option('honeypress_user_before_1_3_8', false)) {
    //detect old user and set value
    $tromas_service_title=get_theme_mod('home_service_section_title');
    $tromas_service_discription=get_theme_mod('home_service_section_discription');
    $tromas_blog_title=get_theme_mod('home_news_section_title');
    $tromas_blog_discription=get_theme_mod('home_news_section_discription');
    $tromas_slider_title=get_theme_mod('home_slider_title');
    $tromas_slider_discription=get_theme_mod('home_slider_discription');
    $tromas_testimonial_title=get_theme_mod('home_testimonial_section_title');
    $tromas_testimonial__discription=get_theme_mod('home_testimonial_section_discription');
    $tromas_footer_credit=get_theme_mod('footer_copyright');

    if ($tromas_service_title !=null || $tromas_service_discription !=null || $tromas_blog_title !=null || $tromas_blog_discription !=null || $tromas_slider_title !=null || $tromas_slider_discription !=null || $tromas_testimonial_title !=null || $tromas_testimonial__discription !=null || $tromas_footer_credit !=null )  {
        add_option('honeypress_user_before_1_3_8', 'old');

    } else {
        add_option('honeypress_user_before_1_3_8', 'new');
    }
}

function tromas_footer_section_hook()
{
?>
<footer class="site-footer">
  <div class="container">
      <?php if(is_active_sidebar('footer-sidebar-1') || is_active_sidebar('footer-sidebar-2') || is_active_sidebar('footer-sidebar-3')): ?>
      <div class="seprator-line"></div>
        <?php get_template_part('sidebar','footer');
      endif;?>
  </div>
  <?php
  $tromas_user=get_option('honeypress_user_before_1_3_8');
  if($tromas_user=='old'){?>
    <div class="site-info text-center">
       <?php $tromas_footer_copyright = get_theme_mod('footer_copyright','<p>'. __( 'Proudly powered by <a href="https://wordpress.org"> WordPress</a> | Theme: <a href="https://spicethemes.com" rel="nofollow">Tromas</a> by SpiceThemes', 'tromas' ).'</p>'); ?>
       <?php echo wp_kses_post($tromas_footer_copyright);?>
    </div>
<?php } else{?>
    <div class="site-info text-center">
         <p><?php esc_html_e( 'Proudly powered by', 'tromas' ); ?> <a href="<?php echo esc_url( __( 'https://wordpress.org', 'tromas' ) ); ?>"><?php esc_html_e( 'WordPress', 'tromas' ); ?> </a> <?php esc_html_e( '| Theme:', 'tromas' ); ?> <a href="<?php echo esc_url( __( 'https://spicethemes.com', 'tromas' ) ); ?>" rel="nofollow"> <?php esc_html_e( 'Tromas', 'tromas' ); ?></a> <?php esc_html_e( 'by SpiceThemes', 'tromas' );?></p>
    </div>
<?php } ?>
</footer>
<?php
}
add_action('tromas_footer_section_hook','tromas_footer_section_hook');

add_action('wp_head','tromas_sticky_header');
function tromas_sticky_header(){
  ?>
  <script>
  jQuery(document).ready(function ( jQuery ) {
 jQuery(window).bind('scroll', function () {
      if (window.matchMedia("(max-width: 150px)").matches)
        {
             //console.log("This is a mobile device.");
            jQuery('.navbar-light.custom').removeClass('stickymenu');
            jQuery('.navbar-brand.custom-logo').show();
            jQuery(".navbar-brand.sticky-logo").hide();
        } else {
            // The viewport is at least 768 pixels wide
                if (jQuery(window).scrollTop() > 100)
                {
                      jQuery('.header-sticky').addClass('stickymenu');
                      jQuery(".navbar-brand.sticky-logo").show();
                      jQuery(".navbar-brand.custom-logo").hide();
                } else {
                      jQuery('.header-sticky').removeClass('stickymenu');
                      jQuery(".navbar-brand.sticky-logo").hide();
                      jQuery(".navbar-brand.custom-logo").show();
                }
          }
        });
});

</script>
  <?php
}

//Add Masonry Layout
add_action('wp_footer', 'tromas_custom_script');

function tromas_custom_script() {

    wp_reset_query();
    ?>
    <script>
        jQuery(document).ready(function (jQuery) {
            jQuery("#blog-masonry2").mpmansory(
                    {
                        childrenClass: 'item', // default is a div
                        columnClasses: 'padding', //add classes to items
                        breakpoints: {
                            xl: 4, //Change masonry column here like 2, 3, 4 column
                            lg: 4,
                            md: 6,
                            sm: 12,
                            xs: 12


                        },
                        distributeBy: {order: false, height: false, attr: 'data-order', attrOrder: 'asc'}, //default distribute by order, options => order: true/false, height: true/false, attr => 'data-order', attrOrder=> 'asc'/'desc'
                        onload: function (items) {
                            //make somthing with items
                        }
                    }
            );
        });
    </script>
    <?php
}

//Remove Footer section
function tromas_remove_customize_register( $wp_customize ) {

   $wp_customize->remove_section( 'footer_section');

}
add_action( 'customize_register', 'tromas_remove_customize_register',11);
